# hep-basestack

[![Coverage Status](https://coveralls.io/repos/github/achim1/hepbasestack/badge.svg?branch=master)](https://coveralls.io/github/achim1/hepbasestack?branch=master)
[![Documentation Status](https://readthedocs.org/projects/hepbasestack/badge/?version=latest)](https://hepbasestack.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/achim1/hepbasestack.svg?branch=master)](https://travis-ci.org/achim1/hepbasestack)


A collection of (hopefully) useful tools:

- logging facility

- pre-set matplotlib styles

- reasonable matplotlib figure sizes

- a list slicer

- ipython notebook detector

...

### hepbasestack?

hep : high-energy particle physics. Package is supposed to be at the bottmo of the software stack used in hep.
Might be useful elsewhere

### Installation

`pip install hepbasestack`
